@@ -766,8 +766,8 @@ struct Job {
 		if(this->command.size() == 1 && this->pull_user()) {
 			this->debackslashpercentise(this->command[0], [&](auto && segment, auto) { this->execstart += segment; });
 
-			uid_t uid;
-			gid_t gid;
+			uid_t uid{};
+			gid_t gid{};
 			if(this->user_uid)
 				uid = setfsuid(this->user_uid);
 			if(this->user_gid)
@@ -867,6 +867,7 @@ struct Job {
 
 		std::fputs("[Service]\n", into);
 		std::fprintf(into, "User=%.*s\n", FORMAT_SV(this->user));
+		std::fputs("WorkingDirectory=-~\n", into);
 		std::fputs("Type=oneshot\n", into);
 		std::fputs("IgnoreSIGPIPE=false\n", into);
 		std::fputs("SyslogFacility=cron\n", into);
@@ -1304,10 +1305,10 @@ static auto realmain() -> int {
 		       //                     (but save the starting hour for daily, weekly, and monthly)
 		       if(job.line.find("/etc/cron.hourly"sv) != std::string_view::npos)
 			       return;
-		       for(auto && disableable_period : {"daily"sv, "weekly"sv, "monthly"sv})
-			       if(job.line.find("/etc/cron."s += disableable_period) != std::string_view::npos) {
+		       for(auto && disableable_dir : {"/etc/cron.daily"sv, "/etc/cron.weekly"sv, "/etc/cron.monthly"sv})
+			       if(job.line.find(disableable_dir) != std::string_view::npos) {
 				       if(auto hour = *job.timespec_hour.begin(); hour != Job::TIMESPEC_ASTERISK)
-					       distro_start_hour[disableable_period] = hour;
+					       distro_start_hour[disableable_dir.substr("/etc/cron."sv.size())] = hour;
 
 				       return;
 			       }
@@ -1355,6 +1356,8 @@ static auto realmain() -> int {
 				if(is_backup(directory.c_str(), basename))
 					return;
 				auto filename            = (directory + '/') += basename;
+				if(access(filename.c_str(), X_OK))
+					return;
 				std::string_view command = filename;
 				Job job{filename, filename};
 				job.persistent        = true;
